@@ -5,6 +5,7 @@ import contextlib
 import errno
 import glob
 import itertools
+import json
 import logging
 import multiprocessing
 import operator
@@ -18,9 +19,11 @@ from typing import Any, Dict, Union, Optional, List, TextIO, Mapping
 import rich.emoji
 import rich.progress
 
+from ... import __version__
 from ._base import Command, CommandExit, InvalidArgument
 from .annotate import Annotate
 from .._utils import patch_showwarnings
+from ...model import ProductType
 
 
 class Run(Annotate):  # noqa: D101
@@ -46,12 +49,16 @@ class Run(Annotate):  # noqa: D101
                                           Biopython format string. GECCO is able
                                           to recognize FASTA and GenBank files
                                           automatically if this is not given.
-            -o <out>, --output-dir <out>  the directory in which to write the
-                                          output files. [default: .]
             -j <jobs>, --jobs <jobs>      the number of CPUs to use for
                                           multithreading. Use 0 to use all of the
                                           available CPUs. [default: 0]
 
+        Parameters - Output:
+            -o <out>, --output-dir <out>  the directory in which to write the
+                                          output files. [default: .]
+            --antismash-sideload          write an AntiSMASH v6 sideload JSON
+                                          file next to the output files.
+
         Parameters - Domain Annotation:
             -e <e>, --e-filter <e>        the e-value cutoff for protein domains
                                           to be included. [default: 1e-5]
@@ -89,6 +96,7 @@ class Run(Annotate):  # noqa: D101
             self.model = self._check_flag("--model")
             self.hmm = self._check_flag("--hmm")
             self.output_dir = self._check_flag("--output-dir")
+            self.antismash_sideload = self._check_flag("--antismash-sideload", bool)
         except InvalidArgument:
             raise CommandExit(1)
 
@@ -105,7 +113,10 @@ class Run(Annotate):  # noqa: D101
 
         # Check if output files already exist
         base, _ = os.path.splitext(os.path.basename(self.genome))
-        for ext in ["features.tsv", "clusters.tsv"]:
+        output_exts = ["features.tsv", "clusters.tsv"]
+        if self.antismash_sideload:
+            output_exts.append("sideload.json")
+        for ext in output_exts:
             if os.path.isfile(os.path.join(self.output_dir, f"{base}.{ext}")):
                 self.warn("Output folder contains files that will be overwritten")
                 break
@@ -195,6 +206,55 @@ class Run(Annotate):  # noqa: D101
             self.info("Writing", f"cluster [bold blue]{cluster.id}[/] to", repr(gbk_out), level=1)
             SeqIO.write(cluster.to_seq_record(), gbk_out, "genbank")
 
+    def _write_sideload_json(self, clusters):
+        # record version and important parameters
+        data = {
+            "records": [],
+            "tool": {
+                "name": "GECCO",
+                "version": __version__,
+                "description": "Biosynthetic Gene Cluster prediction with Conditional Random Fields.",
+                "configuration": {
+                    "cds": repr(self.cds),
+                    "e-filter": repr(self.e_filter),
+                    "postproc": repr(self.postproc),
+                    "threshold": repr(self.threshold),
+                }
+            }
+        }
+        # record if non-standard HMM or model was used
+        if self.hmm:
+            data["tool"]["configuration"]["hmm"] = list(self.hmm)
+        if self.model:
+            data["tool"]["configuration"]["model"] = self.model
+        # create a record per sequence
+        for seq_id, seq_clusters in itertools.groupby(clusters, key=lambda cluster: cluster.source.id):
+            data["records"].append({"name": seq_id, "subregions": []})
+            for cluster in seq_clusters:
+                ty = ";".join(sorted(ty.name for ty in cluster.type.unpack())) or "Unknown"
+                data["records"][-1]["subregions"].append({
+                    "start": cluster.start,
+                    "end": cluster.end,
+                    "label": ty,
+                    "details": {
+                        "average_p": f"{cluster.average_probability:.3f}",
+                        "max_p": f"{cluster.maximum_probability:.3f}",
+                        "alkaloid_probability": f"{cluster.type_probabilities.get(ProductType.Alkaloid, 0.0):.3f}",
+                        "polyketide_probability": f"{cluster.type_probabilities.get(ProductType.Polyketide, 0.0):.3f}",
+                        "ripp_probability": f"{cluster.type_probabilities.get(ProductType.RiPP, 0.0):.3f}",
+                        "saccharide_probability": f"{cluster.type_probabilities.get(ProductType.Saccharide, 0.0):.3f}",
+                        "terpene_probability": f"{cluster.type_probabilities.get(ProductType.Terpene, 0.0):.3f}",
+                        "nrp_probability": f"{cluster.type_probabilities.get(ProductType.NRP, 0.0):.3f}",
+                        "other_probability": f"{cluster.type_probabilities.get(ProductType.Other, 0.0):.3f}",
+                    }
+                })
+        # write the JSON file to the output folder
+        base, _ = os.path.splitext(os.path.basename(self.genome))
+        sideload_out = os.path.join(self.output_dir, f"{base}.sideload.json")
+        self.info("Writing", "sideload JSON to", repr(sideload_out), level=1)
+        with open(sideload_out, "w") as out:
+            json.dump(data, out, sort_keys=True, indent=4)
+
     # ---
 
     def execute(self, ctx: contextlib.ExitStack) -> int:  # noqa: D102
@@ -230,6 +290,8 @@ class Run(Annotate):  # noqa: D101
             self.info("Writing", "result files to folder", repr(self.output_dir), level=1)
             self._write_cluster_table(clusters)
             self._write_clusters(clusters)
+            if self.antismash_sideload:
+                self._write_sideload_json(clusters)
             self.success("Found", len(clusters), "biosynthetic gene clusters", level=0)
         except CommandExit as cexit:
             return cexit.code
